Accept -Wno-all, -Wno-extra and -Wno-unused like GCC.
[cparser] / ast_t.h
diff --git a/ast_t.h b/ast_t.h
index 79418c5..cb8b674 100644 (file)
--- a/ast_t.h
+++ b/ast_t.h
@@ -152,8 +152,8 @@ typedef enum {
        case EXPR_UNARY_ASSUME:                \
        case EXPR_UNARY_BITFIELD_EXTRACT:
 
-struct context_t {
-       declaration_t *declarations;  /**< List of declarations in this context. */
+struct scope_t {
+       declaration_t *declarations;  /**< List of declarations in this scope. */
 };
 
 struct expression_base_t {
@@ -172,7 +172,7 @@ struct const_expression_t {
 
 struct string_literal_expression_t {
        expression_base_t  expression;
-       const char        *value;
+       string_t           value;
 };
 
 struct wide_string_literal_expression_t {
@@ -360,8 +360,8 @@ struct initializer_list_t {
 };
 
 struct initializer_string_t {
-       initializer_base_t  initializer;
-       const char         *string;
+       initializer_base_t initializer;
+       string_t           string;
 };
 
 struct initializer_wide_string_t {
@@ -397,6 +397,7 @@ struct declaration_t {
        decl_modifiers_t    modifiers;
        unsigned int        address_taken : 1;
        unsigned int        is_inline     : 1;
+       unsigned int        used          : 1;  /**< Set if the declaration is used. */
        type_t             *type;
        symbol_t           *symbol;
        source_position_t   source_position;
@@ -406,13 +407,15 @@ struct declaration_t {
                initializer_t  *initializer;
                expression_t   *enum_value;
        } init;
-       context_t           context;
-       context_t          *parent_context;
+       scope_t             scope;
+       scope_t            *parent_scope;
 
/** next declaration in a context */
        declaration_t      *next;
        /** next declaration with same symbol */
        declaration_t      *symbol_next;
+       /** next variable/parameter in function scope/global scope */
+       declaration_t      *next_var;
 
        /* the following fields are used in ast2firm module */
        unsigned char       declaration_kind;
@@ -457,7 +460,7 @@ struct return_statement_t {
 struct compound_statement_t {
        statement_base_t  statement;
        statement_t      *statements;
-       context_t         context;
+       scope_t           scope;
 };
 
 struct declaration_statement_t {
@@ -482,7 +485,8 @@ struct switch_statement_t {
 
 struct goto_statement_t {
        statement_base_t  statement;
-       declaration_t    *label;
+       declaration_t    *label;     /**< The destination label. */
+       goto_statement_t *next;      /**< links all goto statements of a function */
 };
 
 struct case_label_statement_t {
@@ -493,9 +497,10 @@ struct case_label_statement_t {
 };
 
 struct label_statement_t {
-       statement_base_t  statement;
-       declaration_t    *label;
-       statement_t      *label_statement;
+       statement_base_t   statement;
+       declaration_t     *label;
+       statement_t       *label_statement;
+       label_statement_t *next;            /**< links all label statements of a function */
 };
 
 struct expression_statement_t {
@@ -521,24 +526,24 @@ struct for_statement_t {
        expression_t     *condition;
        expression_t     *step;
        statement_t      *body;
-       context_t         context;
+       scope_t           scope;
 };
 
 struct asm_constraint_t {
-       const char       *constraints;
+       string_t          constraints;
        expression_t     *expression;
        symbol_t         *symbol;
        asm_constraint_t *next;
 };
 
 struct asm_clobber_t {
-       const char    *clobber;
+       string_t       clobber;
        asm_clobber_t *next;
 };
 
 struct asm_statement_t {
        statement_base_t  statement;
-       const char       *asm_text;
+       string_t          asm_text;
        asm_constraint_t *inputs;
        asm_constraint_t *outputs;
        asm_clobber_t    *clobbers;
@@ -564,7 +569,7 @@ union statement_t {
 };
 
 struct translation_unit_t {
-       context_t context;
+       scope_t scope;
 };
 
 static inline
@@ -406,13 +407,15 @@ struct declaration_t {
 
-       /** next declaration in a context */
+       /** next declaration in a scope */
        declaration_t      *next;
        /** next declaration with same symbol */